﻿using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Web.Caching;
using System.ComponentModel;
using System.Data.Common;

/// <summary>
/// Zusammenfassungsbeschreibung für TestData
/// </summary>
/// 
[DataObject(true)]
public class TestData
{
    public TestData()
    {
    }
    static public DataSet DataSet
    {
        get
        {
            const string cacheKey = "AjaxMitASPTeil1";
            Cache cache = HttpContext.Current.Cache;
            if (cache[cacheKey] == null)
            {
                DataSet ds = new DataSet("pubs");
                ds.ReadXmlSchema(HttpContext.Current.Server.MapPath("~/App_data/pubs.data.xsd"));
                ds.ReadXml(HttpContext.Current.Server.MapPath("~/App_data/pubs.data.xml"), XmlReadMode.Auto);
                string[] files = new string[2];
                files[0] = HttpContext.Current.Server.MapPath("~/App_data/pubs.data.xsd");
                files[1] = HttpContext.Current.Server.MapPath("~/App_data/pubs.data.xml");
                CacheDependency cd = new CacheDependency(files);
                cache.Add(cacheKey, ds, cd, Cache.NoAbsoluteExpiration, new TimeSpan(0, 30, 0), CacheItemPriority.Normal, null);
            }
            return (DataSet)cache[cacheKey];
        }
    }
    private DataView GetRelationView(string relationName, string rowFilter)
    {
        string keyFormat;

        DataRelation dr = DataSet.Relations[relationName];
        DataTable dt = dr.ParentTable;
        if (dr.ChildColumns[0].DataType == typeof(string))
        {
            keyFormat = "{0} = '{1}'";
        }
        else
        {
            keyFormat = "{0} = {1}";
        }

        DataRow[] row = dt.Select(rowFilter);
        if (row != null && row.Length == 1)
        {
            return GetView(dr.ChildTable, string.Format(keyFormat, dr.ChildColumns[0].ColumnName, row[0][dr.ParentColumns[0].ColumnName]));
        }
        return null;
    }
    private DataTable GetRelationTable(string relationName, string rowFilter)
    {
        string keyFormat;

        DataRelation dr = DataSet.Relations[relationName];
        DataTable dt = dr.ParentTable;
        if (dr.ChildColumns[0].DataType == typeof(string))
        {
            keyFormat = "{0} = '{1}'";
        }
        else
        {
            keyFormat = "{0} = {1}";
        }

        DataRow[] row = dt.Select(rowFilter);
        if (row != null && row.Length == 1)
        {
            return GetTable(dr.ChildTable.TableName, string.Format(keyFormat, dr.ChildColumns[0].ColumnName, row[0][dr.ParentColumns[0].ColumnName]));
        }
        return null;
    }
    private DataView GetView(string tableName, string rowFilter)
    {
        if (rowFilter != null)
        {
            DataView dv = new DataView(DataSet.Tables[tableName]);
            dv.RowFilter = rowFilter;
            return dv;
        }
        else
        {
            return DataSet.Tables[tableName].DefaultView;
        }
    }
    private DataTable GetTable(string tableName, string rowFilter)
    {
        DataTable dt = DataSet.Tables[tableName];
        dt.Select(rowFilter);
        return dt.Copy();
    }
    private DataView GetView(DataTable table, string rowFilter)
    {
        if (rowFilter != null)
        {
            DataView dv = new DataView(table);
            dv.RowFilter = rowFilter;
            return dv.ToTable().DefaultView;
        }
        else
        {
            return table.DefaultView;
        }
    }
    private DataView GetView(string tableName)
    {
        return GetView(tableName, null);
    }
    [DataObjectMethod(DataObjectMethodType.Select)]
    public DataView SelectAuthors()
    {
        return GetView("authors");
    }
    [DataObjectMethod(DataObjectMethodType.Select)]
    public DataView SelectAuthor(string au_id)
    {
        return GetView("authors", string.Format("au_id = '{0}'", au_id));
    }
    [DataObjectMethod(DataObjectMethodType.Select)]
    public DataView SelectTitlesByAuthor(string au_id)
    {
        string rowFilter = string.Format("au_id = '{0}'", au_id);
        return GetRelationView("titleauthor_titles", rowFilter);
    }
    [DataObjectMethod(DataObjectMethodType.Select)]
    public DataView SelectTitles()
    {
        return GetView("titles");
    }

    [DataObjectMethod(DataObjectMethodType.Select)]
    public DataView SelectPublishers()
    {
        return GetView("publishers", null);
    }
    [DataObjectMethod(DataObjectMethodType.Select)]
    public DataView SelectTitlesByPublisher(string pub_id)
    {
        string rowFilter = string.Format("pub_id = '{0}'", pub_id);
        return GetRelationView("publishers_titles", rowFilter);
    }
    [DataObjectMethod(DataObjectMethodType.Select)]
    public DataView SelectAuthorsByTitle(string title_id)
    {
        string rowFilter = string.Format("title_id = '{0}'", title_id);
        return GetRelationView("titleauthor_authors", rowFilter);
    }
}
